import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AccountMemberConfig extends cdktf.TerraformMetaArguments {
    /**
    * Account ID to create the account member in.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/account_member#account_id AccountMember#account_id}
    */
    readonly accountId?: string;
    /**
    * The email address of the user who you wish to manage. Following creation, this field becomes read only via the API and cannot be updated.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/account_member#email_address AccountMember#email_address}
    */
    readonly emailAddress: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/account_member#id AccountMember#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * List of account role IDs that you want to assign to a member.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/account_member#role_ids AccountMember#role_ids}
    */
    readonly roleIds: string[];
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare/r/account_member cloudflare_account_member}
*/
export declare class AccountMember extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_account_member";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare/r/account_member cloudflare_account_member} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AccountMemberConfig
    */
    constructor(scope: Construct, id: string, config: AccountMemberConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _emailAddress?;
    get emailAddress(): string;
    set emailAddress(value: string);
    get emailAddressInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _roleIds?;
    get roleIds(): string[];
    set roleIds(value: string[]);
    get roleIdsInput(): string[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
