import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface FallbackDomainConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain#account_id FallbackDomain#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain#id FallbackDomain#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * domains block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain#domains FallbackDomain#domains}
    */
    readonly domains: FallbackDomainDomains[] | cdktf.IResolvable;
}
export interface FallbackDomainDomains {
    /**
    * A description of the fallback domain, displayed in the client UI.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain#description FallbackDomain#description}
    */
    readonly description?: string;
    /**
    * A list of IP addresses to handle domain resolution.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain#dns_server FallbackDomain#dns_server}
    */
    readonly dnsServer?: string[];
    /**
    * The domain suffix to match when resolving locally.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain#suffix FallbackDomain#suffix}
    */
    readonly suffix?: string;
}
export declare function fallbackDomainDomainsToTerraform(struct?: FallbackDomainDomains | cdktf.IResolvable): any;
export declare class FallbackDomainDomainsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): FallbackDomainDomains | cdktf.IResolvable | undefined;
    set internalValue(value: FallbackDomainDomains | cdktf.IResolvable | undefined);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _dnsServer?;
    get dnsServer(): string[];
    set dnsServer(value: string[]);
    resetDnsServer(): void;
    get dnsServerInput(): string[] | undefined;
    private _suffix?;
    get suffix(): string;
    set suffix(value: string);
    resetSuffix(): void;
    get suffixInput(): string | undefined;
}
export declare class FallbackDomainDomainsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: FallbackDomainDomains[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): FallbackDomainDomainsOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain cloudflare_fallback_domain}
*/
export declare class FallbackDomain extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_fallback_domain";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare/r/fallback_domain cloudflare_fallback_domain} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options FallbackDomainConfig
    */
    constructor(scope: Construct, id: string, config: FallbackDomainConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _domains;
    get domains(): FallbackDomainDomainsList;
    putDomains(value: FallbackDomainDomains[] | cdktf.IResolvable): void;
    get domainsInput(): cdktf.IResolvable | FallbackDomainDomains[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
