import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IpsecTunnelConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#account_id IpsecTunnel#account_id}
    */
    readonly accountId?: string;
    /**
    * Specifies if this tunnel may use a null cipher (ENCR_NULL) in Phase 2. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#allow_null_cipher IpsecTunnel#allow_null_cipher}
    */
    readonly allowNullCipher?: boolean | cdktf.IResolvable;
    /**
    * IP address assigned to the Cloudflare side of the IPsec tunnel.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#cloudflare_endpoint IpsecTunnel#cloudflare_endpoint}
    */
    readonly cloudflareEndpoint: string;
    /**
    * IP address assigned to the customer side of the IPsec tunnel.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#customer_endpoint IpsecTunnel#customer_endpoint}
    */
    readonly customerEndpoint: string;
    /**
    * An optional description of the IPsec tunnel.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#description IpsecTunnel#description}
    */
    readonly description?: string;
    /**
    * `remote_id` in the form of a fqdn. This value is generated by cloudflare.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#fqdn_id IpsecTunnel#fqdn_id}
    */
    readonly fqdnId?: string;
    /**
    * Specifies if ICMP tunnel health checks are enabled. Default: `true`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#health_check_enabled IpsecTunnel#health_check_enabled}
    */
    readonly healthCheckEnabled?: boolean | cdktf.IResolvable;
    /**
    * The IP address of the customer endpoint that will receive tunnel health checks. Default: `<customer_gre_endpoint>`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#health_check_target IpsecTunnel#health_check_target}
    */
    readonly healthCheckTarget?: string;
    /**
    * Specifies the ICMP echo type for the health check (`request` or `reply`). Available values: `request`, `reply` Default: `reply`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#health_check_type IpsecTunnel#health_check_type}
    */
    readonly healthCheckType?: string;
    /**
    * `remote_id` as a hex string. This value is generated by cloudflare.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#hex_id IpsecTunnel#hex_id}
    */
    readonly hexId?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#id IpsecTunnel#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * 31-bit prefix (/31 in CIDR notation) supporting 2 hosts, one for each side of the tunnel.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#interface_address IpsecTunnel#interface_address}
    */
    readonly interfaceAddress: string;
    /**
    * Name of the IPsec tunnel.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#name IpsecTunnel#name}
    */
    readonly name: string;
    /**
    * Pre shared key to be used with the IPsec tunnel. If left unset, it will be autogenerated.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#psk IpsecTunnel#psk}
    */
    readonly psk?: string;
    /**
    * ID to be used while setting up the IPsec tunnel. This value is generated by cloudflare.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#remote_id IpsecTunnel#remote_id}
    */
    readonly remoteId?: string;
    /**
    * `remote_id` in the form of an email address. This value is generated by cloudflare.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel#user_id IpsecTunnel#user_id}
    */
    readonly userId?: string;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel cloudflare_ipsec_tunnel}
*/
export declare class IpsecTunnel extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_ipsec_tunnel";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare/r/ipsec_tunnel cloudflare_ipsec_tunnel} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IpsecTunnelConfig
    */
    constructor(scope: Construct, id: string, config: IpsecTunnelConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _allowNullCipher?;
    get allowNullCipher(): boolean | cdktf.IResolvable;
    set allowNullCipher(value: boolean | cdktf.IResolvable);
    resetAllowNullCipher(): void;
    get allowNullCipherInput(): boolean | cdktf.IResolvable | undefined;
    private _cloudflareEndpoint?;
    get cloudflareEndpoint(): string;
    set cloudflareEndpoint(value: string);
    get cloudflareEndpointInput(): string | undefined;
    private _customerEndpoint?;
    get customerEndpoint(): string;
    set customerEndpoint(value: string);
    get customerEndpointInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _fqdnId?;
    get fqdnId(): string;
    set fqdnId(value: string);
    resetFqdnId(): void;
    get fqdnIdInput(): string | undefined;
    private _healthCheckEnabled?;
    get healthCheckEnabled(): boolean | cdktf.IResolvable;
    set healthCheckEnabled(value: boolean | cdktf.IResolvable);
    resetHealthCheckEnabled(): void;
    get healthCheckEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _healthCheckTarget?;
    get healthCheckTarget(): string;
    set healthCheckTarget(value: string);
    resetHealthCheckTarget(): void;
    get healthCheckTargetInput(): string | undefined;
    private _healthCheckType?;
    get healthCheckType(): string;
    set healthCheckType(value: string);
    resetHealthCheckType(): void;
    get healthCheckTypeInput(): string | undefined;
    private _hexId?;
    get hexId(): string;
    set hexId(value: string);
    resetHexId(): void;
    get hexIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _interfaceAddress?;
    get interfaceAddress(): string;
    set interfaceAddress(value: string);
    get interfaceAddressInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _psk?;
    get psk(): string;
    set psk(value: string);
    resetPsk(): void;
    get pskInput(): string | undefined;
    private _remoteId?;
    get remoteId(): string;
    set remoteId(value: string);
    resetRemoteId(): void;
    get remoteIdInput(): string | undefined;
    private _userId?;
    get userId(): string;
    set userId(value: string);
    resetUserId(): void;
    get userIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
