import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LoadBalancerConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#default_pool_ids LoadBalancer#default_pool_ids}
    */
    readonly defaultPoolIds: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#description LoadBalancer#description}
    */
    readonly description?: string;
    /**
    * Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#enabled LoadBalancer#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#fallback_pool_id LoadBalancer#fallback_pool_id}
    */
    readonly fallbackPoolId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#id LoadBalancer#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#name LoadBalancer#name}
    */
    readonly name: string;
    /**
    * Defaults to `false`. Conflicts with `ttl`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#proxied LoadBalancer#proxied}
    */
    readonly proxied?: boolean | cdktf.IResolvable;
    /**
    * Defaults to `none`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#session_affinity LoadBalancer#session_affinity}
    */
    readonly sessionAffinity?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#session_affinity_attributes LoadBalancer#session_affinity_attributes}
    */
    readonly sessionAffinityAttributes?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#session_affinity_ttl LoadBalancer#session_affinity_ttl}
    */
    readonly sessionAffinityTtl?: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#steering_policy LoadBalancer#steering_policy}
    */
    readonly steeringPolicy?: string;
    /**
    * Conflicts with `proxied`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#ttl LoadBalancer#ttl}
    */
    readonly ttl?: number;
    /**
    * The zone identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#zone_id LoadBalancer#zone_id}
    */
    readonly zoneId: string;
    /**
    * country_pools block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#country_pools LoadBalancer#country_pools}
    */
    readonly countryPools?: LoadBalancerCountryPools[] | cdktf.IResolvable;
    /**
    * pop_pools block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pop_pools LoadBalancer#pop_pools}
    */
    readonly popPools?: LoadBalancerPopPools[] | cdktf.IResolvable;
    /**
    * region_pools block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#region_pools LoadBalancer#region_pools}
    */
    readonly regionPools?: LoadBalancerRegionPools[] | cdktf.IResolvable;
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#rules LoadBalancer#rules}
    */
    readonly rules?: LoadBalancerRules[] | cdktf.IResolvable;
}
export interface LoadBalancerCountryPools {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#country LoadBalancer#country}
    */
    readonly country: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pool_ids LoadBalancer#pool_ids}
    */
    readonly poolIds: string[];
}
export declare function loadBalancerCountryPoolsToTerraform(struct?: LoadBalancerCountryPools | cdktf.IResolvable): any;
export declare class LoadBalancerCountryPoolsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerCountryPools | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerCountryPools | cdktf.IResolvable | undefined);
    private _country?;
    get country(): string;
    set country(value: string);
    get countryInput(): string | undefined;
    private _poolIds?;
    get poolIds(): string[];
    set poolIds(value: string[]);
    get poolIdsInput(): string[] | undefined;
}
export declare class LoadBalancerCountryPoolsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerCountryPools[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerCountryPoolsOutputReference;
}
export interface LoadBalancerPopPools {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pool_ids LoadBalancer#pool_ids}
    */
    readonly poolIds: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pop LoadBalancer#pop}
    */
    readonly pop: string;
}
export declare function loadBalancerPopPoolsToTerraform(struct?: LoadBalancerPopPools | cdktf.IResolvable): any;
export declare class LoadBalancerPopPoolsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerPopPools | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerPopPools | cdktf.IResolvable | undefined);
    private _poolIds?;
    get poolIds(): string[];
    set poolIds(value: string[]);
    get poolIdsInput(): string[] | undefined;
    private _pop?;
    get pop(): string;
    set pop(value: string);
    get popInput(): string | undefined;
}
export declare class LoadBalancerPopPoolsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerPopPools[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerPopPoolsOutputReference;
}
export interface LoadBalancerRegionPools {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pool_ids LoadBalancer#pool_ids}
    */
    readonly poolIds: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#region LoadBalancer#region}
    */
    readonly region: string;
}
export declare function loadBalancerRegionPoolsToTerraform(struct?: LoadBalancerRegionPools | cdktf.IResolvable): any;
export declare class LoadBalancerRegionPoolsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerRegionPools | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerRegionPools | cdktf.IResolvable | undefined);
    private _poolIds?;
    get poolIds(): string[];
    set poolIds(value: string[]);
    get poolIdsInput(): string[] | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export declare class LoadBalancerRegionPoolsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerRegionPools[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerRegionPoolsOutputReference;
}
export interface LoadBalancerRulesFixedResponse {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#content_type LoadBalancer#content_type}
    */
    readonly contentType?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#location LoadBalancer#location}
    */
    readonly location?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#message_body LoadBalancer#message_body}
    */
    readonly messageBody?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#status_code LoadBalancer#status_code}
    */
    readonly statusCode?: number;
}
export declare function loadBalancerRulesFixedResponseToTerraform(struct?: LoadBalancerRulesFixedResponseOutputReference | LoadBalancerRulesFixedResponse): any;
export declare class LoadBalancerRulesFixedResponseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): LoadBalancerRulesFixedResponse | undefined;
    set internalValue(value: LoadBalancerRulesFixedResponse | undefined);
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _messageBody?;
    get messageBody(): string;
    set messageBody(value: string);
    resetMessageBody(): void;
    get messageBodyInput(): string | undefined;
    private _statusCode?;
    get statusCode(): number;
    set statusCode(value: number);
    resetStatusCode(): void;
    get statusCodeInput(): number | undefined;
}
export interface LoadBalancerRulesOverridesCountryPools {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#country LoadBalancer#country}
    */
    readonly country: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pool_ids LoadBalancer#pool_ids}
    */
    readonly poolIds: string[];
}
export declare function loadBalancerRulesOverridesCountryPoolsToTerraform(struct?: LoadBalancerRulesOverridesCountryPools | cdktf.IResolvable): any;
export declare class LoadBalancerRulesOverridesCountryPoolsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerRulesOverridesCountryPools | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerRulesOverridesCountryPools | cdktf.IResolvable | undefined);
    private _country?;
    get country(): string;
    set country(value: string);
    get countryInput(): string | undefined;
    private _poolIds?;
    get poolIds(): string[];
    set poolIds(value: string[]);
    get poolIdsInput(): string[] | undefined;
}
export declare class LoadBalancerRulesOverridesCountryPoolsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerRulesOverridesCountryPools[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerRulesOverridesCountryPoolsOutputReference;
}
export interface LoadBalancerRulesOverridesPopPools {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pool_ids LoadBalancer#pool_ids}
    */
    readonly poolIds: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pop LoadBalancer#pop}
    */
    readonly pop: string;
}
export declare function loadBalancerRulesOverridesPopPoolsToTerraform(struct?: LoadBalancerRulesOverridesPopPools | cdktf.IResolvable): any;
export declare class LoadBalancerRulesOverridesPopPoolsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerRulesOverridesPopPools | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerRulesOverridesPopPools | cdktf.IResolvable | undefined);
    private _poolIds?;
    get poolIds(): string[];
    set poolIds(value: string[]);
    get poolIdsInput(): string[] | undefined;
    private _pop?;
    get pop(): string;
    set pop(value: string);
    get popInput(): string | undefined;
}
export declare class LoadBalancerRulesOverridesPopPoolsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerRulesOverridesPopPools[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerRulesOverridesPopPoolsOutputReference;
}
export interface LoadBalancerRulesOverridesRegionPools {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pool_ids LoadBalancer#pool_ids}
    */
    readonly poolIds: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#region LoadBalancer#region}
    */
    readonly region: string;
}
export declare function loadBalancerRulesOverridesRegionPoolsToTerraform(struct?: LoadBalancerRulesOverridesRegionPools | cdktf.IResolvable): any;
export declare class LoadBalancerRulesOverridesRegionPoolsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerRulesOverridesRegionPools | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerRulesOverridesRegionPools | cdktf.IResolvable | undefined);
    private _poolIds?;
    get poolIds(): string[];
    set poolIds(value: string[]);
    get poolIdsInput(): string[] | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    get regionInput(): string | undefined;
}
export declare class LoadBalancerRulesOverridesRegionPoolsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerRulesOverridesRegionPools[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerRulesOverridesRegionPoolsOutputReference;
}
export interface LoadBalancerRulesOverrides {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#default_pools LoadBalancer#default_pools}
    */
    readonly defaultPools?: string[];
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#fallback_pool LoadBalancer#fallback_pool}
    */
    readonly fallbackPool?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#session_affinity LoadBalancer#session_affinity}
    */
    readonly sessionAffinity?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#session_affinity_attributes LoadBalancer#session_affinity_attributes}
    */
    readonly sessionAffinityAttributes?: {
        [key: string]: string;
    };
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#session_affinity_ttl LoadBalancer#session_affinity_ttl}
    */
    readonly sessionAffinityTtl?: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#steering_policy LoadBalancer#steering_policy}
    */
    readonly steeringPolicy?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#ttl LoadBalancer#ttl}
    */
    readonly ttl?: number;
    /**
    * country_pools block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#country_pools LoadBalancer#country_pools}
    */
    readonly countryPools?: LoadBalancerRulesOverridesCountryPools[] | cdktf.IResolvable;
    /**
    * pop_pools block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#pop_pools LoadBalancer#pop_pools}
    */
    readonly popPools?: LoadBalancerRulesOverridesPopPools[] | cdktf.IResolvable;
    /**
    * region_pools block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#region_pools LoadBalancer#region_pools}
    */
    readonly regionPools?: LoadBalancerRulesOverridesRegionPools[] | cdktf.IResolvable;
}
export declare function loadBalancerRulesOverridesToTerraform(struct?: LoadBalancerRulesOverrides | cdktf.IResolvable): any;
export declare class LoadBalancerRulesOverridesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerRulesOverrides | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerRulesOverrides | cdktf.IResolvable | undefined);
    private _defaultPools?;
    get defaultPools(): string[];
    set defaultPools(value: string[]);
    resetDefaultPools(): void;
    get defaultPoolsInput(): string[] | undefined;
    private _fallbackPool?;
    get fallbackPool(): string;
    set fallbackPool(value: string);
    resetFallbackPool(): void;
    get fallbackPoolInput(): string | undefined;
    private _sessionAffinity?;
    get sessionAffinity(): string;
    set sessionAffinity(value: string);
    resetSessionAffinity(): void;
    get sessionAffinityInput(): string | undefined;
    private _sessionAffinityAttributes?;
    get sessionAffinityAttributes(): {
        [key: string]: string;
    };
    set sessionAffinityAttributes(value: {
        [key: string]: string;
    });
    resetSessionAffinityAttributes(): void;
    get sessionAffinityAttributesInput(): {
        [key: string]: string;
    } | undefined;
    private _sessionAffinityTtl?;
    get sessionAffinityTtl(): number;
    set sessionAffinityTtl(value: number);
    resetSessionAffinityTtl(): void;
    get sessionAffinityTtlInput(): number | undefined;
    private _steeringPolicy?;
    get steeringPolicy(): string;
    set steeringPolicy(value: string);
    resetSteeringPolicy(): void;
    get steeringPolicyInput(): string | undefined;
    private _ttl?;
    get ttl(): number;
    set ttl(value: number);
    resetTtl(): void;
    get ttlInput(): number | undefined;
    private _countryPools;
    get countryPools(): LoadBalancerRulesOverridesCountryPoolsList;
    putCountryPools(value: LoadBalancerRulesOverridesCountryPools[] | cdktf.IResolvable): void;
    resetCountryPools(): void;
    get countryPoolsInput(): cdktf.IResolvable | LoadBalancerRulesOverridesCountryPools[] | undefined;
    private _popPools;
    get popPools(): LoadBalancerRulesOverridesPopPoolsList;
    putPopPools(value: LoadBalancerRulesOverridesPopPools[] | cdktf.IResolvable): void;
    resetPopPools(): void;
    get popPoolsInput(): cdktf.IResolvable | LoadBalancerRulesOverridesPopPools[] | undefined;
    private _regionPools;
    get regionPools(): LoadBalancerRulesOverridesRegionPoolsList;
    putRegionPools(value: LoadBalancerRulesOverridesRegionPools[] | cdktf.IResolvable): void;
    resetRegionPools(): void;
    get regionPoolsInput(): cdktf.IResolvable | LoadBalancerRulesOverridesRegionPools[] | undefined;
}
export declare class LoadBalancerRulesOverridesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerRulesOverrides[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerRulesOverridesOutputReference;
}
export interface LoadBalancerRules {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#condition LoadBalancer#condition}
    */
    readonly condition?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#disabled LoadBalancer#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#name LoadBalancer#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#priority LoadBalancer#priority}
    */
    readonly priority?: number;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#terminates LoadBalancer#terminates}
    */
    readonly terminates?: boolean | cdktf.IResolvable;
    /**
    * fixed_response block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#fixed_response LoadBalancer#fixed_response}
    */
    readonly fixedResponse?: LoadBalancerRulesFixedResponse;
    /**
    * overrides block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer#overrides LoadBalancer#overrides}
    */
    readonly overrides?: LoadBalancerRulesOverrides[] | cdktf.IResolvable;
}
export declare function loadBalancerRulesToTerraform(struct?: LoadBalancerRules | cdktf.IResolvable): any;
export declare class LoadBalancerRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): LoadBalancerRules | cdktf.IResolvable | undefined;
    set internalValue(value: LoadBalancerRules | cdktf.IResolvable | undefined);
    private _condition?;
    get condition(): string;
    set condition(value: string);
    resetCondition(): void;
    get conditionInput(): string | undefined;
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _priority?;
    get priority(): number;
    set priority(value: number);
    resetPriority(): void;
    get priorityInput(): number | undefined;
    private _terminates?;
    get terminates(): boolean | cdktf.IResolvable;
    set terminates(value: boolean | cdktf.IResolvable);
    resetTerminates(): void;
    get terminatesInput(): boolean | cdktf.IResolvable | undefined;
    private _fixedResponse;
    get fixedResponse(): LoadBalancerRulesFixedResponseOutputReference;
    putFixedResponse(value: LoadBalancerRulesFixedResponse): void;
    resetFixedResponse(): void;
    get fixedResponseInput(): LoadBalancerRulesFixedResponse | undefined;
    private _overrides;
    get overrides(): LoadBalancerRulesOverridesList;
    putOverrides(value: LoadBalancerRulesOverrides[] | cdktf.IResolvable): void;
    resetOverrides(): void;
    get overridesInput(): cdktf.IResolvable | LoadBalancerRulesOverrides[] | undefined;
}
export declare class LoadBalancerRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: LoadBalancerRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): LoadBalancerRulesOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer cloudflare_load_balancer}
*/
export declare class LoadBalancer extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_load_balancer";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare/r/load_balancer cloudflare_load_balancer} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LoadBalancerConfig
    */
    constructor(scope: Construct, id: string, config: LoadBalancerConfig);
    get createdOn(): string;
    private _defaultPoolIds?;
    get defaultPoolIds(): string[];
    set defaultPoolIds(value: string[]);
    get defaultPoolIdsInput(): string[] | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _fallbackPoolId?;
    get fallbackPoolId(): string;
    set fallbackPoolId(value: string);
    get fallbackPoolIdInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get modifiedOn(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _proxied?;
    get proxied(): boolean | cdktf.IResolvable;
    set proxied(value: boolean | cdktf.IResolvable);
    resetProxied(): void;
    get proxiedInput(): boolean | cdktf.IResolvable | undefined;
    private _sessionAffinity?;
    get sessionAffinity(): string;
    set sessionAffinity(value: string);
    resetSessionAffinity(): void;
    get sessionAffinityInput(): string | undefined;
    private _sessionAffinityAttributes?;
    get sessionAffinityAttributes(): {
        [key: string]: string;
    };
    set sessionAffinityAttributes(value: {
        [key: string]: string;
    });
    resetSessionAffinityAttributes(): void;
    get sessionAffinityAttributesInput(): {
        [key: string]: string;
    } | undefined;
    private _sessionAffinityTtl?;
    get sessionAffinityTtl(): number;
    set sessionAffinityTtl(value: number);
    resetSessionAffinityTtl(): void;
    get sessionAffinityTtlInput(): number | undefined;
    private _steeringPolicy?;
    get steeringPolicy(): string;
    set steeringPolicy(value: string);
    resetSteeringPolicy(): void;
    get steeringPolicyInput(): string | undefined;
    private _ttl?;
    get ttl(): number;
    set ttl(value: number);
    resetTtl(): void;
    get ttlInput(): number | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    private _countryPools;
    get countryPools(): LoadBalancerCountryPoolsList;
    putCountryPools(value: LoadBalancerCountryPools[] | cdktf.IResolvable): void;
    resetCountryPools(): void;
    get countryPoolsInput(): cdktf.IResolvable | LoadBalancerCountryPools[] | undefined;
    private _popPools;
    get popPools(): LoadBalancerPopPoolsList;
    putPopPools(value: LoadBalancerPopPools[] | cdktf.IResolvable): void;
    resetPopPools(): void;
    get popPoolsInput(): cdktf.IResolvable | LoadBalancerPopPools[] | undefined;
    private _regionPools;
    get regionPools(): LoadBalancerRegionPoolsList;
    putRegionPools(value: LoadBalancerRegionPools[] | cdktf.IResolvable): void;
    resetRegionPools(): void;
    get regionPoolsInput(): cdktf.IResolvable | LoadBalancerRegionPools[] | undefined;
    private _rules;
    get rules(): LoadBalancerRulesList;
    putRules(value: LoadBalancerRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | LoadBalancerRules[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
