import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ManagedHeadersConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#id ManagedHeaders#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The zone identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#zone_id ManagedHeaders#zone_id}
    */
    readonly zoneId: string;
    /**
    * managed_request_headers block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#managed_request_headers ManagedHeaders#managed_request_headers}
    */
    readonly managedRequestHeaders?: ManagedHeadersManagedRequestHeaders[] | cdktf.IResolvable;
    /**
    * managed_response_headers block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#managed_response_headers ManagedHeaders#managed_response_headers}
    */
    readonly managedResponseHeaders?: ManagedHeadersManagedResponseHeaders[] | cdktf.IResolvable;
}
export interface ManagedHeadersManagedRequestHeaders {
    /**
    * Whether the headers rule is active.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#enabled ManagedHeaders#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Unique headers rule identifier.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#id ManagedHeaders#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function managedHeadersManagedRequestHeadersToTerraform(struct?: ManagedHeadersManagedRequestHeaders | cdktf.IResolvable): any;
export declare class ManagedHeadersManagedRequestHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ManagedHeadersManagedRequestHeaders | cdktf.IResolvable | undefined;
    set internalValue(value: ManagedHeadersManagedRequestHeaders | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
export declare class ManagedHeadersManagedRequestHeadersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ManagedHeadersManagedRequestHeaders[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ManagedHeadersManagedRequestHeadersOutputReference;
}
export interface ManagedHeadersManagedResponseHeaders {
    /**
    * Whether the headers rule is active.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#enabled ManagedHeaders#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Unique headers rule identifier.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers#id ManagedHeaders#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
}
export declare function managedHeadersManagedResponseHeadersToTerraform(struct?: ManagedHeadersManagedResponseHeaders | cdktf.IResolvable): any;
export declare class ManagedHeadersManagedResponseHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): ManagedHeadersManagedResponseHeaders | cdktf.IResolvable | undefined;
    set internalValue(value: ManagedHeadersManagedResponseHeaders | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
}
export declare class ManagedHeadersManagedResponseHeadersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: ManagedHeadersManagedResponseHeaders[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): ManagedHeadersManagedResponseHeadersOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers cloudflare_managed_headers}
*/
export declare class ManagedHeaders extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_managed_headers";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare/r/managed_headers cloudflare_managed_headers} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ManagedHeadersConfig
    */
    constructor(scope: Construct, id: string, config: ManagedHeadersConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    private _managedRequestHeaders;
    get managedRequestHeaders(): ManagedHeadersManagedRequestHeadersList;
    putManagedRequestHeaders(value: ManagedHeadersManagedRequestHeaders[] | cdktf.IResolvable): void;
    resetManagedRequestHeaders(): void;
    get managedRequestHeadersInput(): cdktf.IResolvable | ManagedHeadersManagedRequestHeaders[] | undefined;
    private _managedResponseHeaders;
    get managedResponseHeaders(): ManagedHeadersManagedResponseHeadersList;
    putManagedResponseHeaders(value: ManagedHeadersManagedResponseHeaders[] | cdktf.IResolvable): void;
    resetManagedResponseHeaders(): void;
    get managedResponseHeadersInput(): cdktf.IResolvable | ManagedHeadersManagedResponseHeaders[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
