import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RulesetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. Conflicts with `zone_id`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#account_id Ruleset#account_id}
    */
    readonly accountId?: string;
    /**
    * Brief summary of the ruleset and its intended use.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#description Ruleset#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#id Ruleset#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Type of Ruleset to create. Available values: `custom`, `managed`, `root`, `schema`, `zone`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#kind Ruleset#kind}
    */
    readonly kind: string;
    /**
    * Name of the ruleset.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#name Ruleset#name}
    */
    readonly name: string;
    /**
    * Point in the request/response lifecycle where the ruleset will be created. Available values: `ddos_l4`, `ddos_l7`, `http_log_custom_fields`, `http_request_cache_settings`, `http_request_firewall_custom`, `http_request_firewall_managed`, `http_request_late_transform`, `http_request_late_transform_managed`, `http_request_main`, `http_request_origin`, `http_request_dynamic_redirect`, `http_request_redirect`, `http_request_sanitize`, `http_request_transform`, `http_response_firewall_managed`, `http_response_headers_transform`, `http_response_headers_transform_managed`, `magic_transit`, `http_ratelimit`, `http_request_sbfm`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#phase Ruleset#phase}
    */
    readonly phase: string;
    /**
    * Name of entitlement that is shareable between entities.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#shareable_entitlement_name Ruleset#shareable_entitlement_name}
    */
    readonly shareableEntitlementName?: string;
    /**
    * The zone identifier to target for the resource. Conflicts with `account_id`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#zone_id Ruleset#zone_id}
    */
    readonly zoneId?: string;
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#rules Ruleset#rules}
    */
    readonly rules?: RulesetRules[] | cdktf.IResolvable;
}
export interface RulesetRulesActionParametersBrowserTtl {
    /**
    * Default browser TTL.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#default Ruleset#default}
    */
    readonly default?: number;
    /**
    * Mode of the browser TTL.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#mode Ruleset#mode}
    */
    readonly mode: string;
}
export declare function rulesetRulesActionParametersBrowserTtlToTerraform(struct?: RulesetRulesActionParametersBrowserTtlOutputReference | RulesetRulesActionParametersBrowserTtl): any;
export declare class RulesetRulesActionParametersBrowserTtlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersBrowserTtl | undefined;
    set internalValue(value: RulesetRulesActionParametersBrowserTtl | undefined);
    private _default?;
    get default(): number;
    set default(value: number);
    resetDefault(): void;
    get defaultInput(): number | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
}
export interface RulesetRulesActionParametersCacheKeyCustomKeyCookie {
    /**
    * List of cookies to check for presence in the custom key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#check_presence Ruleset#check_presence}
    */
    readonly checkPresence?: string[];
    /**
    * List of cookies to include in the custom key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#include Ruleset#include}
    */
    readonly include?: string[];
}
export declare function rulesetRulesActionParametersCacheKeyCustomKeyCookieToTerraform(struct?: RulesetRulesActionParametersCacheKeyCustomKeyCookieOutputReference | RulesetRulesActionParametersCacheKeyCustomKeyCookie): any;
export declare class RulesetRulesActionParametersCacheKeyCustomKeyCookieOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersCacheKeyCustomKeyCookie | undefined;
    set internalValue(value: RulesetRulesActionParametersCacheKeyCustomKeyCookie | undefined);
    private _checkPresence?;
    get checkPresence(): string[];
    set checkPresence(value: string[]);
    resetCheckPresence(): void;
    get checkPresenceInput(): string[] | undefined;
    private _include?;
    get include(): string[];
    set include(value: string[]);
    resetInclude(): void;
    get includeInput(): string[] | undefined;
}
export interface RulesetRulesActionParametersCacheKeyCustomKeyHeader {
    /**
    * List of headers to check for presence in the custom key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#check_presence Ruleset#check_presence}
    */
    readonly checkPresence?: string[];
    /**
    * Exclude the origin header from the custom key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#exclude_origin Ruleset#exclude_origin}
    */
    readonly excludeOrigin?: boolean | cdktf.IResolvable;
    /**
    * List of headers to include in the custom key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#include Ruleset#include}
    */
    readonly include?: string[];
}
export declare function rulesetRulesActionParametersCacheKeyCustomKeyHeaderToTerraform(struct?: RulesetRulesActionParametersCacheKeyCustomKeyHeaderOutputReference | RulesetRulesActionParametersCacheKeyCustomKeyHeader): any;
export declare class RulesetRulesActionParametersCacheKeyCustomKeyHeaderOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersCacheKeyCustomKeyHeader | undefined;
    set internalValue(value: RulesetRulesActionParametersCacheKeyCustomKeyHeader | undefined);
    private _checkPresence?;
    get checkPresence(): string[];
    set checkPresence(value: string[]);
    resetCheckPresence(): void;
    get checkPresenceInput(): string[] | undefined;
    private _excludeOrigin?;
    get excludeOrigin(): boolean | cdktf.IResolvable;
    set excludeOrigin(value: boolean | cdktf.IResolvable);
    resetExcludeOrigin(): void;
    get excludeOriginInput(): boolean | cdktf.IResolvable | undefined;
    private _include?;
    get include(): string[];
    set include(value: string[]);
    resetInclude(): void;
    get includeInput(): string[] | undefined;
}
export interface RulesetRulesActionParametersCacheKeyCustomKeyHost {
    /**
    * Resolve hostname to IP address.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#resolved Ruleset#resolved}
    */
    readonly resolved?: boolean | cdktf.IResolvable;
}
export declare function rulesetRulesActionParametersCacheKeyCustomKeyHostToTerraform(struct?: RulesetRulesActionParametersCacheKeyCustomKeyHostOutputReference | RulesetRulesActionParametersCacheKeyCustomKeyHost): any;
export declare class RulesetRulesActionParametersCacheKeyCustomKeyHostOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersCacheKeyCustomKeyHost | undefined;
    set internalValue(value: RulesetRulesActionParametersCacheKeyCustomKeyHost | undefined);
    private _resolved?;
    get resolved(): boolean | cdktf.IResolvable;
    set resolved(value: boolean | cdktf.IResolvable);
    resetResolved(): void;
    get resolvedInput(): boolean | cdktf.IResolvable | undefined;
}
export interface RulesetRulesActionParametersCacheKeyCustomKeyQueryString {
    /**
    * List of query string parameters to exclude from the custom key. Conflicts with "include".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#exclude Ruleset#exclude}
    */
    readonly exclude?: string[];
    /**
    * List of query string parameters to include in the custom key. Conflicts with "exclude".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#include Ruleset#include}
    */
    readonly include?: string[];
}
export declare function rulesetRulesActionParametersCacheKeyCustomKeyQueryStringToTerraform(struct?: RulesetRulesActionParametersCacheKeyCustomKeyQueryStringOutputReference | RulesetRulesActionParametersCacheKeyCustomKeyQueryString): any;
export declare class RulesetRulesActionParametersCacheKeyCustomKeyQueryStringOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersCacheKeyCustomKeyQueryString | undefined;
    set internalValue(value: RulesetRulesActionParametersCacheKeyCustomKeyQueryString | undefined);
    private _exclude?;
    get exclude(): string[];
    set exclude(value: string[]);
    resetExclude(): void;
    get excludeInput(): string[] | undefined;
    private _include?;
    get include(): string[];
    set include(value: string[]);
    resetInclude(): void;
    get includeInput(): string[] | undefined;
}
export interface RulesetRulesActionParametersCacheKeyCustomKeyUser {
    /**
    * Add device type to the custom key. Conflicts with "cache_key.cache_by_device_type".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#device_type Ruleset#device_type}
    */
    readonly deviceType?: boolean | cdktf.IResolvable;
    /**
    * Add geo data to the custom key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#geo Ruleset#geo}
    */
    readonly geo?: boolean | cdktf.IResolvable;
    /**
    * Add language data to the custom key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#lang Ruleset#lang}
    */
    readonly lang?: boolean | cdktf.IResolvable;
}
export declare function rulesetRulesActionParametersCacheKeyCustomKeyUserToTerraform(struct?: RulesetRulesActionParametersCacheKeyCustomKeyUserOutputReference | RulesetRulesActionParametersCacheKeyCustomKeyUser): any;
export declare class RulesetRulesActionParametersCacheKeyCustomKeyUserOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersCacheKeyCustomKeyUser | undefined;
    set internalValue(value: RulesetRulesActionParametersCacheKeyCustomKeyUser | undefined);
    private _deviceType?;
    get deviceType(): boolean | cdktf.IResolvable;
    set deviceType(value: boolean | cdktf.IResolvable);
    resetDeviceType(): void;
    get deviceTypeInput(): boolean | cdktf.IResolvable | undefined;
    private _geo?;
    get geo(): boolean | cdktf.IResolvable;
    set geo(value: boolean | cdktf.IResolvable);
    resetGeo(): void;
    get geoInput(): boolean | cdktf.IResolvable | undefined;
    private _lang?;
    get lang(): boolean | cdktf.IResolvable;
    set lang(value: boolean | cdktf.IResolvable);
    resetLang(): void;
    get langInput(): boolean | cdktf.IResolvable | undefined;
}
export interface RulesetRulesActionParametersCacheKeyCustomKey {
    /**
    * cookie block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#cookie Ruleset#cookie}
    */
    readonly cookie?: RulesetRulesActionParametersCacheKeyCustomKeyCookie;
    /**
    * header block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#header Ruleset#header}
    */
    readonly header?: RulesetRulesActionParametersCacheKeyCustomKeyHeader;
    /**
    * host block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#host Ruleset#host}
    */
    readonly host?: RulesetRulesActionParametersCacheKeyCustomKeyHost;
    /**
    * query_string block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#query_string Ruleset#query_string}
    */
    readonly queryString?: RulesetRulesActionParametersCacheKeyCustomKeyQueryString;
    /**
    * user block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#user Ruleset#user}
    */
    readonly user?: RulesetRulesActionParametersCacheKeyCustomKeyUser;
}
export declare function rulesetRulesActionParametersCacheKeyCustomKeyToTerraform(struct?: RulesetRulesActionParametersCacheKeyCustomKeyOutputReference | RulesetRulesActionParametersCacheKeyCustomKey): any;
export declare class RulesetRulesActionParametersCacheKeyCustomKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersCacheKeyCustomKey | undefined;
    set internalValue(value: RulesetRulesActionParametersCacheKeyCustomKey | undefined);
    private _cookie;
    get cookie(): RulesetRulesActionParametersCacheKeyCustomKeyCookieOutputReference;
    putCookie(value: RulesetRulesActionParametersCacheKeyCustomKeyCookie): void;
    resetCookie(): void;
    get cookieInput(): RulesetRulesActionParametersCacheKeyCustomKeyCookie | undefined;
    private _header;
    get header(): RulesetRulesActionParametersCacheKeyCustomKeyHeaderOutputReference;
    putHeader(value: RulesetRulesActionParametersCacheKeyCustomKeyHeader): void;
    resetHeader(): void;
    get headerInput(): RulesetRulesActionParametersCacheKeyCustomKeyHeader | undefined;
    private _host;
    get host(): RulesetRulesActionParametersCacheKeyCustomKeyHostOutputReference;
    putHost(value: RulesetRulesActionParametersCacheKeyCustomKeyHost): void;
    resetHost(): void;
    get hostInput(): RulesetRulesActionParametersCacheKeyCustomKeyHost | undefined;
    private _queryString;
    get queryString(): RulesetRulesActionParametersCacheKeyCustomKeyQueryStringOutputReference;
    putQueryString(value: RulesetRulesActionParametersCacheKeyCustomKeyQueryString): void;
    resetQueryString(): void;
    get queryStringInput(): RulesetRulesActionParametersCacheKeyCustomKeyQueryString | undefined;
    private _user;
    get user(): RulesetRulesActionParametersCacheKeyCustomKeyUserOutputReference;
    putUser(value: RulesetRulesActionParametersCacheKeyCustomKeyUser): void;
    resetUser(): void;
    get userInput(): RulesetRulesActionParametersCacheKeyCustomKeyUser | undefined;
}
export interface RulesetRulesActionParametersCacheKey {
    /**
    * Cache by device type. Conflicts with "custom_key.user.device_type".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#cache_by_device_type Ruleset#cache_by_device_type}
    */
    readonly cacheByDeviceType?: boolean | cdktf.IResolvable;
    /**
    * Cache deception armor.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#cache_deception_armor Ruleset#cache_deception_armor}
    */
    readonly cacheDeceptionArmor?: boolean | cdktf.IResolvable;
    /**
    * Ignore query strings order.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#ignore_query_strings_order Ruleset#ignore_query_strings_order}
    */
    readonly ignoreQueryStringsOrder?: boolean | cdktf.IResolvable;
    /**
    * custom_key block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#custom_key Ruleset#custom_key}
    */
    readonly customKey?: RulesetRulesActionParametersCacheKeyCustomKey;
}
export declare function rulesetRulesActionParametersCacheKeyToTerraform(struct?: RulesetRulesActionParametersCacheKeyOutputReference | RulesetRulesActionParametersCacheKey): any;
export declare class RulesetRulesActionParametersCacheKeyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersCacheKey | undefined;
    set internalValue(value: RulesetRulesActionParametersCacheKey | undefined);
    private _cacheByDeviceType?;
    get cacheByDeviceType(): boolean | cdktf.IResolvable;
    set cacheByDeviceType(value: boolean | cdktf.IResolvable);
    resetCacheByDeviceType(): void;
    get cacheByDeviceTypeInput(): boolean | cdktf.IResolvable | undefined;
    private _cacheDeceptionArmor?;
    get cacheDeceptionArmor(): boolean | cdktf.IResolvable;
    set cacheDeceptionArmor(value: boolean | cdktf.IResolvable);
    resetCacheDeceptionArmor(): void;
    get cacheDeceptionArmorInput(): boolean | cdktf.IResolvable | undefined;
    private _ignoreQueryStringsOrder?;
    get ignoreQueryStringsOrder(): boolean | cdktf.IResolvable;
    set ignoreQueryStringsOrder(value: boolean | cdktf.IResolvable);
    resetIgnoreQueryStringsOrder(): void;
    get ignoreQueryStringsOrderInput(): boolean | cdktf.IResolvable | undefined;
    private _customKey;
    get customKey(): RulesetRulesActionParametersCacheKeyCustomKeyOutputReference;
    putCustomKey(value: RulesetRulesActionParametersCacheKeyCustomKey): void;
    resetCustomKey(): void;
    get customKeyInput(): RulesetRulesActionParametersCacheKeyCustomKey | undefined;
}
export interface RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange {
    /**
    * From status code.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#from Ruleset#from}
    */
    readonly from?: number;
    /**
    * To status code.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#to Ruleset#to}
    */
    readonly to?: number;
}
export declare function rulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRangeToTerraform(struct?: RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange | cdktf.IResolvable): any;
export declare class RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRangeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange | cdktf.IResolvable | undefined;
    set internalValue(value: RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange | cdktf.IResolvable | undefined);
    private _from?;
    get from(): number;
    set from(value: number);
    resetFrom(): void;
    get fromInput(): number | undefined;
    private _to?;
    get to(): number;
    set to(value: number);
    resetTo(): void;
    get toInput(): number | undefined;
}
export declare class RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRangeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRangeOutputReference;
}
export interface RulesetRulesActionParametersEdgeTtlStatusCodeTtl {
    /**
    * Status code for which the edge TTL is applied. Conflicts with "status_code_range".
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status_code Ruleset#status_code}
    */
    readonly statusCode?: number;
    /**
    * Status code edge TTL value.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#value Ruleset#value}
    */
    readonly value: number;
    /**
    * status_code_range block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status_code_range Ruleset#status_code_range}
    */
    readonly statusCodeRange?: RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange[] | cdktf.IResolvable;
}
export declare function rulesetRulesActionParametersEdgeTtlStatusCodeTtlToTerraform(struct?: RulesetRulesActionParametersEdgeTtlStatusCodeTtl | cdktf.IResolvable): any;
export declare class RulesetRulesActionParametersEdgeTtlStatusCodeTtlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RulesetRulesActionParametersEdgeTtlStatusCodeTtl | cdktf.IResolvable | undefined;
    set internalValue(value: RulesetRulesActionParametersEdgeTtlStatusCodeTtl | cdktf.IResolvable | undefined);
    private _statusCode?;
    get statusCode(): number;
    set statusCode(value: number);
    resetStatusCode(): void;
    get statusCodeInput(): number | undefined;
    private _value?;
    get value(): number;
    set value(value: number);
    get valueInput(): number | undefined;
    private _statusCodeRange;
    get statusCodeRange(): RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRangeList;
    putStatusCodeRange(value: RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange[] | cdktf.IResolvable): void;
    resetStatusCodeRange(): void;
    get statusCodeRangeInput(): cdktf.IResolvable | RulesetRulesActionParametersEdgeTtlStatusCodeTtlStatusCodeRange[] | undefined;
}
export declare class RulesetRulesActionParametersEdgeTtlStatusCodeTtlList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RulesetRulesActionParametersEdgeTtlStatusCodeTtl[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RulesetRulesActionParametersEdgeTtlStatusCodeTtlOutputReference;
}
export interface RulesetRulesActionParametersEdgeTtl {
    /**
    * Default edge TTL.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#default Ruleset#default}
    */
    readonly default: number;
    /**
    * Mode of the edge TTL.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#mode Ruleset#mode}
    */
    readonly mode: string;
    /**
    * status_code_ttl block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status_code_ttl Ruleset#status_code_ttl}
    */
    readonly statusCodeTtl?: RulesetRulesActionParametersEdgeTtlStatusCodeTtl[] | cdktf.IResolvable;
}
export declare function rulesetRulesActionParametersEdgeTtlToTerraform(struct?: RulesetRulesActionParametersEdgeTtlOutputReference | RulesetRulesActionParametersEdgeTtl): any;
export declare class RulesetRulesActionParametersEdgeTtlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersEdgeTtl | undefined;
    set internalValue(value: RulesetRulesActionParametersEdgeTtl | undefined);
    private _default?;
    get default(): number;
    set default(value: number);
    get defaultInput(): number | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
    private _statusCodeTtl;
    get statusCodeTtl(): RulesetRulesActionParametersEdgeTtlStatusCodeTtlList;
    putStatusCodeTtl(value: RulesetRulesActionParametersEdgeTtlStatusCodeTtl[] | cdktf.IResolvable): void;
    resetStatusCodeTtl(): void;
    get statusCodeTtlInput(): cdktf.IResolvable | RulesetRulesActionParametersEdgeTtlStatusCodeTtl[] | undefined;
}
export interface RulesetRulesActionParametersFromList {
    /**
    * Expression to use for the list lookup.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#key Ruleset#key}
    */
    readonly key: string;
    /**
    * Name of the list.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#name Ruleset#name}
    */
    readonly name: string;
}
export declare function rulesetRulesActionParametersFromListToTerraform(struct?: RulesetRulesActionParametersFromListOutputReference | RulesetRulesActionParametersFromList): any;
export declare class RulesetRulesActionParametersFromListOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersFromList | undefined;
    set internalValue(value: RulesetRulesActionParametersFromList | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
}
export interface RulesetRulesActionParametersFromValueTargetUrl {
    /**
    * Use a value dynamically determined by the Firewall Rules expression language based on Wireshark display filters. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language) documentation for all available fields, operators, and functions. Conflicts with `"value"`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#expression Ruleset#expression}
    */
    readonly expression?: string;
    /**
    * Static value to provide as the HTTP request header value. Conflicts with `"expression"`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#value Ruleset#value}
    */
    readonly value?: string;
}
export declare function rulesetRulesActionParametersFromValueTargetUrlToTerraform(struct?: RulesetRulesActionParametersFromValueTargetUrlOutputReference | RulesetRulesActionParametersFromValueTargetUrl): any;
export declare class RulesetRulesActionParametersFromValueTargetUrlOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersFromValueTargetUrl | undefined;
    set internalValue(value: RulesetRulesActionParametersFromValueTargetUrl | undefined);
    private _expression?;
    get expression(): string;
    set expression(value: string);
    resetExpression(): void;
    get expressionInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export interface RulesetRulesActionParametersFromValue {
    /**
    * Preserve query string for redirect URL.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#preserve_query_string Ruleset#preserve_query_string}
    */
    readonly preserveQueryString?: boolean | cdktf.IResolvable;
    /**
    * Status code for redirect.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status_code Ruleset#status_code}
    */
    readonly statusCode?: number;
    /**
    * target_url block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#target_url Ruleset#target_url}
    */
    readonly targetUrl?: RulesetRulesActionParametersFromValueTargetUrl;
}
export declare function rulesetRulesActionParametersFromValueToTerraform(struct?: RulesetRulesActionParametersFromValueOutputReference | RulesetRulesActionParametersFromValue): any;
export declare class RulesetRulesActionParametersFromValueOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersFromValue | undefined;
    set internalValue(value: RulesetRulesActionParametersFromValue | undefined);
    private _preserveQueryString?;
    get preserveQueryString(): boolean | cdktf.IResolvable;
    set preserveQueryString(value: boolean | cdktf.IResolvable);
    resetPreserveQueryString(): void;
    get preserveQueryStringInput(): boolean | cdktf.IResolvable | undefined;
    private _statusCode?;
    get statusCode(): number;
    set statusCode(value: number);
    resetStatusCode(): void;
    get statusCodeInput(): number | undefined;
    private _targetUrl;
    get targetUrl(): RulesetRulesActionParametersFromValueTargetUrlOutputReference;
    putTargetUrl(value: RulesetRulesActionParametersFromValueTargetUrl): void;
    resetTargetUrl(): void;
    get targetUrlInput(): RulesetRulesActionParametersFromValueTargetUrl | undefined;
}
export interface RulesetRulesActionParametersHeaders {
    /**
    * Use a value dynamically determined by the Firewall Rules expression language based on Wireshark display filters. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language) documentation for all available fields, operators, and functions. Conflicts with `"value"`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#expression Ruleset#expression}
    */
    readonly expression?: string;
    /**
    * Name of the HTTP request header to target.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#name Ruleset#name}
    */
    readonly name?: string;
    /**
    * Action to perform on the HTTP request header. Available values: `remove`, `set`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#operation Ruleset#operation}
    */
    readonly operation?: string;
    /**
    * Static value to provide as the HTTP request header value. Conflicts with `"expression"`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#value Ruleset#value}
    */
    readonly value?: string;
}
export declare function rulesetRulesActionParametersHeadersToTerraform(struct?: RulesetRulesActionParametersHeaders | cdktf.IResolvable): any;
export declare class RulesetRulesActionParametersHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RulesetRulesActionParametersHeaders | cdktf.IResolvable | undefined;
    set internalValue(value: RulesetRulesActionParametersHeaders | cdktf.IResolvable | undefined);
    private _expression?;
    get expression(): string;
    set expression(value: string);
    resetExpression(): void;
    get expressionInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _operation?;
    get operation(): string;
    set operation(value: string);
    resetOperation(): void;
    get operationInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class RulesetRulesActionParametersHeadersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RulesetRulesActionParametersHeaders[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RulesetRulesActionParametersHeadersOutputReference;
}
export interface RulesetRulesActionParametersMatchedData {
    /**
    * Public key to use within WAF Ruleset payload logging to view the HTTP request parameters. You can generate a public key [using the `matched-data-cli` command-line tool](https://developers.cloudflare.com/waf/managed-rulesets/payload-logging/command-line/generate-key-pair) or [in the Cloudflare dashboard](https://developers.cloudflare.com/waf/managed-rulesets/payload-logging/configure).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#public_key Ruleset#public_key}
    */
    readonly publicKey?: string;
}
export declare function rulesetRulesActionParametersMatchedDataToTerraform(struct?: RulesetRulesActionParametersMatchedDataOutputReference | RulesetRulesActionParametersMatchedData): any;
export declare class RulesetRulesActionParametersMatchedDataOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersMatchedData | undefined;
    set internalValue(value: RulesetRulesActionParametersMatchedData | undefined);
    private _publicKey?;
    get publicKey(): string;
    set publicKey(value: string);
    resetPublicKey(): void;
    get publicKeyInput(): string | undefined;
}
export interface RulesetRulesActionParametersOrigin {
    /**
    * Origin Hostname where request is sent.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#host Ruleset#host}
    */
    readonly host?: string;
    /**
    * Origin Port where request is sent.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#port Ruleset#port}
    */
    readonly port?: number;
}
export declare function rulesetRulesActionParametersOriginToTerraform(struct?: RulesetRulesActionParametersOriginOutputReference | RulesetRulesActionParametersOrigin): any;
export declare class RulesetRulesActionParametersOriginOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersOrigin | undefined;
    set internalValue(value: RulesetRulesActionParametersOrigin | undefined);
    private _host?;
    get host(): string;
    set host(value: string);
    resetHost(): void;
    get hostInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
}
export interface RulesetRulesActionParametersOverridesCategories {
    /**
    * Action to perform in the tag-level override. Available values: `block`, `challenge`, `ddos_dynamic`, `execute`, `force_connection_close`, `js_challenge`, `log`, `log_custom_field`, `managed_challenge`, `redirect`, `rewrite`, `route`, `score`, `set_cache_settings`, `skip`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#action Ruleset#action}
    */
    readonly action?: string;
    /**
    * Tag name to apply the ruleset rule override to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#category Ruleset#category}
    */
    readonly category?: string;
    /**
    * Defines if the current tag-level override enables or disables the ruleset rules with the specified tag.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#enabled Ruleset#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Defines if the current tag-level override enables or disables the ruleset rules with the specified tag. Available values: `enabled`, `disabled`. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status Ruleset#status}
    */
    readonly status?: string;
}
export declare function rulesetRulesActionParametersOverridesCategoriesToTerraform(struct?: RulesetRulesActionParametersOverridesCategories | cdktf.IResolvable): any;
export declare class RulesetRulesActionParametersOverridesCategoriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RulesetRulesActionParametersOverridesCategories | cdktf.IResolvable | undefined;
    set internalValue(value: RulesetRulesActionParametersOverridesCategories | cdktf.IResolvable | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
    private _category?;
    get category(): string;
    set category(value: string);
    resetCategory(): void;
    get categoryInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
}
export declare class RulesetRulesActionParametersOverridesCategoriesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RulesetRulesActionParametersOverridesCategories[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RulesetRulesActionParametersOverridesCategoriesOutputReference;
}
export interface RulesetRulesActionParametersOverridesRules {
    /**
    * Action to perform in the rule-level override. Available values: `block`, `challenge`, `ddos_dynamic`, `execute`, `force_connection_close`, `js_challenge`, `log`, `log_custom_field`, `managed_challenge`, `redirect`, `rewrite`, `route`, `score`, `set_cache_settings`, `skip`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#action Ruleset#action}
    */
    readonly action?: string;
    /**
    * Defines if the current rule-level override enables or disables the rule.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#enabled Ruleset#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Rule ID to apply the override to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#id Ruleset#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Anomaly score threshold to apply in the ruleset rule override. Only applicable to modsecurity-based rulesets.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#score_threshold Ruleset#score_threshold}
    */
    readonly scoreThreshold?: number;
    /**
    * Sensitivity level for a ruleset rule override.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#sensitivity_level Ruleset#sensitivity_level}
    */
    readonly sensitivityLevel?: string;
    /**
    * Defines if the current rule-level override enables or disables the rule. Available values: `enabled`, `disabled`. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status Ruleset#status}
    */
    readonly status?: string;
}
export declare function rulesetRulesActionParametersOverridesRulesToTerraform(struct?: RulesetRulesActionParametersOverridesRules | cdktf.IResolvable): any;
export declare class RulesetRulesActionParametersOverridesRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RulesetRulesActionParametersOverridesRules | cdktf.IResolvable | undefined;
    set internalValue(value: RulesetRulesActionParametersOverridesRules | cdktf.IResolvable | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _scoreThreshold?;
    get scoreThreshold(): number;
    set scoreThreshold(value: number);
    resetScoreThreshold(): void;
    get scoreThresholdInput(): number | undefined;
    private _sensitivityLevel?;
    get sensitivityLevel(): string;
    set sensitivityLevel(value: string);
    resetSensitivityLevel(): void;
    get sensitivityLevelInput(): string | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
}
export declare class RulesetRulesActionParametersOverridesRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RulesetRulesActionParametersOverridesRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RulesetRulesActionParametersOverridesRulesOutputReference;
}
export interface RulesetRulesActionParametersOverrides {
    /**
    * Action to perform in the rule-level override. Available values: `block`, `challenge`, `ddos_dynamic`, `execute`, `force_connection_close`, `js_challenge`, `log`, `log_custom_field`, `managed_challenge`, `redirect`, `rewrite`, `route`, `score`, `set_cache_settings`, `skip`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#action Ruleset#action}
    */
    readonly action?: string;
    /**
    * Defines if the current ruleset-level override enables or disables the ruleset.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#enabled Ruleset#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Defines if the current ruleset-level override enables or disables the ruleset. Available values: `enabled`, `disabled`. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status Ruleset#status}
    */
    readonly status?: string;
    /**
    * categories block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#categories Ruleset#categories}
    */
    readonly categories?: RulesetRulesActionParametersOverridesCategories[] | cdktf.IResolvable;
    /**
    * rules block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#rules Ruleset#rules}
    */
    readonly rules?: RulesetRulesActionParametersOverridesRules[] | cdktf.IResolvable;
}
export declare function rulesetRulesActionParametersOverridesToTerraform(struct?: RulesetRulesActionParametersOverridesOutputReference | RulesetRulesActionParametersOverrides): any;
export declare class RulesetRulesActionParametersOverridesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersOverrides | undefined;
    set internalValue(value: RulesetRulesActionParametersOverrides | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
    private _categories;
    get categories(): RulesetRulesActionParametersOverridesCategoriesList;
    putCategories(value: RulesetRulesActionParametersOverridesCategories[] | cdktf.IResolvable): void;
    resetCategories(): void;
    get categoriesInput(): cdktf.IResolvable | RulesetRulesActionParametersOverridesCategories[] | undefined;
    private _rules;
    get rules(): RulesetRulesActionParametersOverridesRulesList;
    putRules(value: RulesetRulesActionParametersOverridesRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | RulesetRulesActionParametersOverridesRules[] | undefined;
}
export interface RulesetRulesActionParametersResponse {
    /**
    * Body content to include in the response.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#content Ruleset#content}
    */
    readonly content?: string;
    /**
    * HTTP content type to send in the response.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#content_type Ruleset#content_type}
    */
    readonly contentType?: string;
    /**
    * HTTP status code to send in the response.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status_code Ruleset#status_code}
    */
    readonly statusCode?: number;
}
export declare function rulesetRulesActionParametersResponseToTerraform(struct?: RulesetRulesActionParametersResponse | cdktf.IResolvable): any;
export declare class RulesetRulesActionParametersResponseOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RulesetRulesActionParametersResponse | cdktf.IResolvable | undefined;
    set internalValue(value: RulesetRulesActionParametersResponse | cdktf.IResolvable | undefined);
    private _content?;
    get content(): string;
    set content(value: string);
    resetContent(): void;
    get contentInput(): string | undefined;
    private _contentType?;
    get contentType(): string;
    set contentType(value: string);
    resetContentType(): void;
    get contentTypeInput(): string | undefined;
    private _statusCode?;
    get statusCode(): number;
    set statusCode(value: number);
    resetStatusCode(): void;
    get statusCodeInput(): number | undefined;
}
export declare class RulesetRulesActionParametersResponseList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RulesetRulesActionParametersResponse[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RulesetRulesActionParametersResponseOutputReference;
}
export interface RulesetRulesActionParametersServeStale {
    /**
    * Disable stale while updating.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#disable_stale_while_updating Ruleset#disable_stale_while_updating}
    */
    readonly disableStaleWhileUpdating?: boolean | cdktf.IResolvable;
}
export declare function rulesetRulesActionParametersServeStaleToTerraform(struct?: RulesetRulesActionParametersServeStaleOutputReference | RulesetRulesActionParametersServeStale): any;
export declare class RulesetRulesActionParametersServeStaleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersServeStale | undefined;
    set internalValue(value: RulesetRulesActionParametersServeStale | undefined);
    private _disableStaleWhileUpdating?;
    get disableStaleWhileUpdating(): boolean | cdktf.IResolvable;
    set disableStaleWhileUpdating(value: boolean | cdktf.IResolvable);
    resetDisableStaleWhileUpdating(): void;
    get disableStaleWhileUpdatingInput(): boolean | cdktf.IResolvable | undefined;
}
export interface RulesetRulesActionParametersUriPath {
    /**
    * Expression that defines the updated (dynamic) value of the URI path or query string component. Uses the Firewall Rules expression language based on Wireshark display filters. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language) documentation for all available fields, operators, and functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#expression Ruleset#expression}
    */
    readonly expression?: string;
    /**
    * Static string value of the updated URI path or query string component.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#value Ruleset#value}
    */
    readonly value?: string;
}
export declare function rulesetRulesActionParametersUriPathToTerraform(struct?: RulesetRulesActionParametersUriPathOutputReference | RulesetRulesActionParametersUriPath): any;
export declare class RulesetRulesActionParametersUriPathOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersUriPath | undefined;
    set internalValue(value: RulesetRulesActionParametersUriPath | undefined);
    private _expression?;
    get expression(): string;
    set expression(value: string);
    resetExpression(): void;
    get expressionInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export interface RulesetRulesActionParametersUriQuery {
    /**
    * Expression that defines the updated (dynamic) value of the URI path or query string component. Uses the Firewall Rules expression language based on Wireshark display filters. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language) documentation for all available fields, operators, and functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#expression Ruleset#expression}
    */
    readonly expression?: string;
    /**
    * Static string value of the updated URI path or query string component.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#value Ruleset#value}
    */
    readonly value?: string;
}
export declare function rulesetRulesActionParametersUriQueryToTerraform(struct?: RulesetRulesActionParametersUriQueryOutputReference | RulesetRulesActionParametersUriQuery): any;
export declare class RulesetRulesActionParametersUriQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersUriQuery | undefined;
    set internalValue(value: RulesetRulesActionParametersUriQuery | undefined);
    private _expression?;
    get expression(): string;
    set expression(value: string);
    resetExpression(): void;
    get expressionInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export interface RulesetRulesActionParametersUri {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#origin Ruleset#origin}
    */
    readonly origin?: boolean | cdktf.IResolvable;
    /**
    * path block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#path Ruleset#path}
    */
    readonly path?: RulesetRulesActionParametersUriPath;
    /**
    * query block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#query Ruleset#query}
    */
    readonly query?: RulesetRulesActionParametersUriQuery;
}
export declare function rulesetRulesActionParametersUriToTerraform(struct?: RulesetRulesActionParametersUriOutputReference | RulesetRulesActionParametersUri): any;
export declare class RulesetRulesActionParametersUriOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParametersUri | undefined;
    set internalValue(value: RulesetRulesActionParametersUri | undefined);
    private _origin?;
    get origin(): boolean | cdktf.IResolvable;
    set origin(value: boolean | cdktf.IResolvable);
    resetOrigin(): void;
    get originInput(): boolean | cdktf.IResolvable | undefined;
    private _path;
    get path(): RulesetRulesActionParametersUriPathOutputReference;
    putPath(value: RulesetRulesActionParametersUriPath): void;
    resetPath(): void;
    get pathInput(): RulesetRulesActionParametersUriPath | undefined;
    private _query;
    get query(): RulesetRulesActionParametersUriQueryOutputReference;
    putQuery(value: RulesetRulesActionParametersUriQuery): void;
    resetQuery(): void;
    get queryInput(): RulesetRulesActionParametersUriQuery | undefined;
}
export interface RulesetRulesActionParameters {
    /**
    * Whether to cache if expression matches.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#cache Ruleset#cache}
    */
    readonly cache?: boolean | cdktf.IResolvable;
    /**
    * List of cookie values to include as part of custom fields logging.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#cookie_fields Ruleset#cookie_fields}
    */
    readonly cookieFields?: string[];
    /**
    * Host Header that request origin receives.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#host_header Ruleset#host_header}
    */
    readonly hostHeader?: string;
    /**
    * Identifier of the action parameter to modify.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#id Ruleset#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#increment Ruleset#increment}
    */
    readonly increment?: number;
    /**
    * Pass-through error page for origin.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#origin_error_page_passthru Ruleset#origin_error_page_passthru}
    */
    readonly originErrorPagePassthru?: boolean | cdktf.IResolvable;
    /**
    * Point in the request/response lifecycle where the ruleset will be created. Available values: `ddos_l4`, `ddos_l7`, `http_log_custom_fields`, `http_request_cache_settings`, `http_request_firewall_custom`, `http_request_firewall_managed`, `http_request_late_transform`, `http_request_late_transform_managed`, `http_request_main`, `http_request_origin`, `http_request_dynamic_redirect`, `http_request_redirect`, `http_request_sanitize`, `http_request_transform`, `http_response_firewall_managed`, `http_response_headers_transform`, `http_response_headers_transform_managed`, `magic_transit`, `http_ratelimit`, `http_request_sbfm`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#phases Ruleset#phases}
    */
    readonly phases?: string[];
    /**
    * Products to target with the actions. Available values: `bic`, `hot`, `ratelimit`, `securityLevel`, `uablock`, `waf`, `zonelockdown`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#products Ruleset#products}
    */
    readonly products?: string[];
    /**
    * List of request headers to include as part of custom fields logging, in lowercase.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#request_fields Ruleset#request_fields}
    */
    readonly requestFields?: string[];
    /**
    * Respect strong ETags.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#respect_strong_etags Ruleset#respect_strong_etags}
    */
    readonly respectStrongEtags?: boolean | cdktf.IResolvable;
    /**
    * List of response headers to include as part of custom fields logging, in lowercase.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#response_fields Ruleset#response_fields}
    */
    readonly responseFields?: string[];
    /**
    * Map of managed WAF rule ID to comma-delimited string of ruleset rule IDs. Example: `rules = { "efb7b8c949ac4650a09736fc376e9aee" = "5de7edfa648c4d6891dc3e7f84534ffa,e3a567afc347477d9702d9047e97d760" }`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#rules Ruleset#rules}
    */
    readonly rules?: {
        [key: string]: string;
    };
    /**
    * Which ruleset ID to target.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#ruleset Ruleset#ruleset}
    */
    readonly ruleset?: string;
    /**
    * List of managed WAF rule IDs to target. Only valid when the `"action"` is set to skip.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#rulesets Ruleset#rulesets}
    */
    readonly rulesets?: string[];
    /**
    * Version of the ruleset to deploy.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#version Ruleset#version}
    */
    readonly version?: string;
    /**
    * browser_ttl block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#browser_ttl Ruleset#browser_ttl}
    */
    readonly browserTtl?: RulesetRulesActionParametersBrowserTtl;
    /**
    * cache_key block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#cache_key Ruleset#cache_key}
    */
    readonly cacheKey?: RulesetRulesActionParametersCacheKey;
    /**
    * edge_ttl block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#edge_ttl Ruleset#edge_ttl}
    */
    readonly edgeTtl?: RulesetRulesActionParametersEdgeTtl;
    /**
    * from_list block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#from_list Ruleset#from_list}
    */
    readonly fromList?: RulesetRulesActionParametersFromList;
    /**
    * from_value block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#from_value Ruleset#from_value}
    */
    readonly fromValue?: RulesetRulesActionParametersFromValue;
    /**
    * headers block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#headers Ruleset#headers}
    */
    readonly headers?: RulesetRulesActionParametersHeaders[] | cdktf.IResolvable;
    /**
    * matched_data block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#matched_data Ruleset#matched_data}
    */
    readonly matchedData?: RulesetRulesActionParametersMatchedData;
    /**
    * origin block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#origin Ruleset#origin}
    */
    readonly origin?: RulesetRulesActionParametersOrigin;
    /**
    * overrides block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#overrides Ruleset#overrides}
    */
    readonly overrides?: RulesetRulesActionParametersOverrides;
    /**
    * response block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#response Ruleset#response}
    */
    readonly response?: RulesetRulesActionParametersResponse[] | cdktf.IResolvable;
    /**
    * serve_stale block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#serve_stale Ruleset#serve_stale}
    */
    readonly serveStale?: RulesetRulesActionParametersServeStale;
    /**
    * uri block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#uri Ruleset#uri}
    */
    readonly uri?: RulesetRulesActionParametersUri;
}
export declare function rulesetRulesActionParametersToTerraform(struct?: RulesetRulesActionParametersOutputReference | RulesetRulesActionParameters): any;
export declare class RulesetRulesActionParametersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesActionParameters | undefined;
    set internalValue(value: RulesetRulesActionParameters | undefined);
    private _cache?;
    get cache(): boolean | cdktf.IResolvable;
    set cache(value: boolean | cdktf.IResolvable);
    resetCache(): void;
    get cacheInput(): boolean | cdktf.IResolvable | undefined;
    private _cookieFields?;
    get cookieFields(): string[];
    set cookieFields(value: string[]);
    resetCookieFields(): void;
    get cookieFieldsInput(): string[] | undefined;
    private _hostHeader?;
    get hostHeader(): string;
    set hostHeader(value: string);
    resetHostHeader(): void;
    get hostHeaderInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _increment?;
    get increment(): number;
    set increment(value: number);
    resetIncrement(): void;
    get incrementInput(): number | undefined;
    private _originErrorPagePassthru?;
    get originErrorPagePassthru(): boolean | cdktf.IResolvable;
    set originErrorPagePassthru(value: boolean | cdktf.IResolvable);
    resetOriginErrorPagePassthru(): void;
    get originErrorPagePassthruInput(): boolean | cdktf.IResolvable | undefined;
    private _phases?;
    get phases(): string[];
    set phases(value: string[]);
    resetPhases(): void;
    get phasesInput(): string[] | undefined;
    private _products?;
    get products(): string[];
    set products(value: string[]);
    resetProducts(): void;
    get productsInput(): string[] | undefined;
    private _requestFields?;
    get requestFields(): string[];
    set requestFields(value: string[]);
    resetRequestFields(): void;
    get requestFieldsInput(): string[] | undefined;
    private _respectStrongEtags?;
    get respectStrongEtags(): boolean | cdktf.IResolvable;
    set respectStrongEtags(value: boolean | cdktf.IResolvable);
    resetRespectStrongEtags(): void;
    get respectStrongEtagsInput(): boolean | cdktf.IResolvable | undefined;
    private _responseFields?;
    get responseFields(): string[];
    set responseFields(value: string[]);
    resetResponseFields(): void;
    get responseFieldsInput(): string[] | undefined;
    private _rules?;
    get rules(): {
        [key: string]: string;
    };
    set rules(value: {
        [key: string]: string;
    });
    resetRules(): void;
    get rulesInput(): {
        [key: string]: string;
    } | undefined;
    private _ruleset?;
    get ruleset(): string;
    set ruleset(value: string);
    resetRuleset(): void;
    get rulesetInput(): string | undefined;
    private _rulesets?;
    get rulesets(): string[];
    set rulesets(value: string[]);
    resetRulesets(): void;
    get rulesetsInput(): string[] | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    resetVersion(): void;
    get versionInput(): string | undefined;
    private _browserTtl;
    get browserTtl(): RulesetRulesActionParametersBrowserTtlOutputReference;
    putBrowserTtl(value: RulesetRulesActionParametersBrowserTtl): void;
    resetBrowserTtl(): void;
    get browserTtlInput(): RulesetRulesActionParametersBrowserTtl | undefined;
    private _cacheKey;
    get cacheKey(): RulesetRulesActionParametersCacheKeyOutputReference;
    putCacheKey(value: RulesetRulesActionParametersCacheKey): void;
    resetCacheKey(): void;
    get cacheKeyInput(): RulesetRulesActionParametersCacheKey | undefined;
    private _edgeTtl;
    get edgeTtl(): RulesetRulesActionParametersEdgeTtlOutputReference;
    putEdgeTtl(value: RulesetRulesActionParametersEdgeTtl): void;
    resetEdgeTtl(): void;
    get edgeTtlInput(): RulesetRulesActionParametersEdgeTtl | undefined;
    private _fromList;
    get fromList(): RulesetRulesActionParametersFromListOutputReference;
    putFromList(value: RulesetRulesActionParametersFromList): void;
    resetFromList(): void;
    get fromListInput(): RulesetRulesActionParametersFromList | undefined;
    private _fromValue;
    get fromValue(): RulesetRulesActionParametersFromValueOutputReference;
    putFromValue(value: RulesetRulesActionParametersFromValue): void;
    resetFromValue(): void;
    get fromValueInput(): RulesetRulesActionParametersFromValue | undefined;
    private _headers;
    get headers(): RulesetRulesActionParametersHeadersList;
    putHeaders(value: RulesetRulesActionParametersHeaders[] | cdktf.IResolvable): void;
    resetHeaders(): void;
    get headersInput(): cdktf.IResolvable | RulesetRulesActionParametersHeaders[] | undefined;
    private _matchedData;
    get matchedData(): RulesetRulesActionParametersMatchedDataOutputReference;
    putMatchedData(value: RulesetRulesActionParametersMatchedData): void;
    resetMatchedData(): void;
    get matchedDataInput(): RulesetRulesActionParametersMatchedData | undefined;
    private _origin;
    get origin(): RulesetRulesActionParametersOriginOutputReference;
    putOrigin(value: RulesetRulesActionParametersOrigin): void;
    resetOrigin(): void;
    get originInput(): RulesetRulesActionParametersOrigin | undefined;
    private _overrides;
    get overrides(): RulesetRulesActionParametersOverridesOutputReference;
    putOverrides(value: RulesetRulesActionParametersOverrides): void;
    resetOverrides(): void;
    get overridesInput(): RulesetRulesActionParametersOverrides | undefined;
    private _response;
    get response(): RulesetRulesActionParametersResponseList;
    putResponse(value: RulesetRulesActionParametersResponse[] | cdktf.IResolvable): void;
    resetResponse(): void;
    get responseInput(): cdktf.IResolvable | RulesetRulesActionParametersResponse[] | undefined;
    private _serveStale;
    get serveStale(): RulesetRulesActionParametersServeStaleOutputReference;
    putServeStale(value: RulesetRulesActionParametersServeStale): void;
    resetServeStale(): void;
    get serveStaleInput(): RulesetRulesActionParametersServeStale | undefined;
    private _uri;
    get uri(): RulesetRulesActionParametersUriOutputReference;
    putUri(value: RulesetRulesActionParametersUri): void;
    resetUri(): void;
    get uriInput(): RulesetRulesActionParametersUri | undefined;
}
export interface RulesetRulesExposedCredentialCheck {
    /**
    * Firewall Rules expression language based on Wireshark display filters for where to check for the "password" value. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#password_expression Ruleset#password_expression}
    */
    readonly passwordExpression?: string;
    /**
    * Firewall Rules expression language based on Wireshark display filters for where to check for the "username" value. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#username_expression Ruleset#username_expression}
    */
    readonly usernameExpression?: string;
}
export declare function rulesetRulesExposedCredentialCheckToTerraform(struct?: RulesetRulesExposedCredentialCheckOutputReference | RulesetRulesExposedCredentialCheck): any;
export declare class RulesetRulesExposedCredentialCheckOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesExposedCredentialCheck | undefined;
    set internalValue(value: RulesetRulesExposedCredentialCheck | undefined);
    private _passwordExpression?;
    get passwordExpression(): string;
    set passwordExpression(value: string);
    resetPasswordExpression(): void;
    get passwordExpressionInput(): string | undefined;
    private _usernameExpression?;
    get usernameExpression(): string;
    set usernameExpression(value: string);
    resetUsernameExpression(): void;
    get usernameExpressionInput(): string | undefined;
}
export interface RulesetRulesLogging {
    /**
    * Override the default logging behavior when a rule is matched.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#enabled Ruleset#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Override the default logging behavior when a rule is matched. Available values: `enabled`, `disabled`. Defaults to `""`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#status Ruleset#status}
    */
    readonly status?: string;
}
export declare function rulesetRulesLoggingToTerraform(struct?: RulesetRulesLoggingOutputReference | RulesetRulesLogging): any;
export declare class RulesetRulesLoggingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesLogging | undefined;
    set internalValue(value: RulesetRulesLogging | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _status?;
    get status(): string;
    set status(value: string);
    resetStatus(): void;
    get statusInput(): string | undefined;
}
export interface RulesetRulesRatelimit {
    /**
    * List of parameters that define how Cloudflare tracks the request rate for this rule.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#characteristics Ruleset#characteristics}
    */
    readonly characteristics?: string[];
    /**
    * Criteria for counting HTTP requests to trigger the Rate Limiting action. Uses the Firewall Rules expression language based on Wireshark display filters. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language) documentation for all available fields, operators, and functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#counting_expression Ruleset#counting_expression}
    */
    readonly countingExpression?: string;
    /**
    * Once the request rate is reached, the Rate Limiting rule blocks further requests for the period of time defined in this field.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#mitigation_timeout Ruleset#mitigation_timeout}
    */
    readonly mitigationTimeout?: number;
    /**
    * The period of time to consider (in seconds) when evaluating the request rate.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#period Ruleset#period}
    */
    readonly period?: number;
    /**
    * The number of requests over the period of time that will trigger the Rate Limiting rule.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#requests_per_period Ruleset#requests_per_period}
    */
    readonly requestsPerPeriod?: number;
    /**
    * Whether to include requests to origin within the Rate Limiting count.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#requests_to_origin Ruleset#requests_to_origin}
    */
    readonly requestsToOrigin?: boolean | cdktf.IResolvable;
}
export declare function rulesetRulesRatelimitToTerraform(struct?: RulesetRulesRatelimitOutputReference | RulesetRulesRatelimit): any;
export declare class RulesetRulesRatelimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RulesetRulesRatelimit | undefined;
    set internalValue(value: RulesetRulesRatelimit | undefined);
    private _characteristics?;
    get characteristics(): string[];
    set characteristics(value: string[]);
    resetCharacteristics(): void;
    get characteristicsInput(): string[] | undefined;
    private _countingExpression?;
    get countingExpression(): string;
    set countingExpression(value: string);
    resetCountingExpression(): void;
    get countingExpressionInput(): string | undefined;
    private _mitigationTimeout?;
    get mitigationTimeout(): number;
    set mitigationTimeout(value: number);
    resetMitigationTimeout(): void;
    get mitigationTimeoutInput(): number | undefined;
    private _period?;
    get period(): number;
    set period(value: number);
    resetPeriod(): void;
    get periodInput(): number | undefined;
    private _requestsPerPeriod?;
    get requestsPerPeriod(): number;
    set requestsPerPeriod(value: number);
    resetRequestsPerPeriod(): void;
    get requestsPerPeriodInput(): number | undefined;
    private _requestsToOrigin?;
    get requestsToOrigin(): boolean | cdktf.IResolvable;
    set requestsToOrigin(value: boolean | cdktf.IResolvable);
    resetRequestsToOrigin(): void;
    get requestsToOriginInput(): boolean | cdktf.IResolvable | undefined;
}
export interface RulesetRules {
    /**
    * Action to perform in the ruleset rule. Available values: `block`, `challenge`, `ddos_dynamic`, `execute`, `force_connection_close`, `js_challenge`, `log`, `log_custom_field`, `managed_challenge`, `redirect`, `rewrite`, `route`, `score`, `set_cache_settings`, `skip`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#action Ruleset#action}
    */
    readonly action?: string;
    /**
    * Brief summary of the ruleset rule and its intended use.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#description Ruleset#description}
    */
    readonly description?: string;
    /**
    * Whether the rule is active.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#enabled Ruleset#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Criteria for an HTTP request to trigger the ruleset rule action. Uses the Firewall Rules expression language based on Wireshark display filters. Refer to the [Firewall Rules language](https://developers.cloudflare.com/firewall/cf-firewall-language) documentation for all available fields, operators, and functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#expression Ruleset#expression}
    */
    readonly expression: string;
    /**
    * action_parameters block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#action_parameters Ruleset#action_parameters}
    */
    readonly actionParameters?: RulesetRulesActionParameters;
    /**
    * exposed_credential_check block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#exposed_credential_check Ruleset#exposed_credential_check}
    */
    readonly exposedCredentialCheck?: RulesetRulesExposedCredentialCheck;
    /**
    * logging block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#logging Ruleset#logging}
    */
    readonly logging?: RulesetRulesLogging;
    /**
    * ratelimit block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset#ratelimit Ruleset#ratelimit}
    */
    readonly ratelimit?: RulesetRulesRatelimit;
}
export declare function rulesetRulesToTerraform(struct?: RulesetRules | cdktf.IResolvable): any;
export declare class RulesetRulesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RulesetRules | cdktf.IResolvable | undefined;
    set internalValue(value: RulesetRules | cdktf.IResolvable | undefined);
    private _action?;
    get action(): string;
    set action(value: string);
    resetAction(): void;
    get actionInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _expression?;
    get expression(): string;
    set expression(value: string);
    get expressionInput(): string | undefined;
    get id(): string;
    get ref(): string;
    get version(): string;
    private _actionParameters;
    get actionParameters(): RulesetRulesActionParametersOutputReference;
    putActionParameters(value: RulesetRulesActionParameters): void;
    resetActionParameters(): void;
    get actionParametersInput(): RulesetRulesActionParameters | undefined;
    private _exposedCredentialCheck;
    get exposedCredentialCheck(): RulesetRulesExposedCredentialCheckOutputReference;
    putExposedCredentialCheck(value: RulesetRulesExposedCredentialCheck): void;
    resetExposedCredentialCheck(): void;
    get exposedCredentialCheckInput(): RulesetRulesExposedCredentialCheck | undefined;
    private _logging;
    get logging(): RulesetRulesLoggingOutputReference;
    putLogging(value: RulesetRulesLogging): void;
    resetLogging(): void;
    get loggingInput(): RulesetRulesLogging | undefined;
    private _ratelimit;
    get ratelimit(): RulesetRulesRatelimitOutputReference;
    putRatelimit(value: RulesetRulesRatelimit): void;
    resetRatelimit(): void;
    get ratelimitInput(): RulesetRulesRatelimit | undefined;
}
export declare class RulesetRulesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RulesetRules[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RulesetRulesOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset cloudflare_ruleset}
*/
export declare class Ruleset extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_ruleset";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare/r/ruleset cloudflare_ruleset} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RulesetConfig
    */
    constructor(scope: Construct, id: string, config: RulesetConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _kind?;
    get kind(): string;
    set kind(value: string);
    get kindInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _phase?;
    get phase(): string;
    set phase(value: string);
    get phaseInput(): string | undefined;
    private _shareableEntitlementName?;
    get shareableEntitlementName(): string;
    set shareableEntitlementName(value: string);
    resetShareableEntitlementName(): void;
    get shareableEntitlementNameInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    private _rules;
    get rules(): RulesetRulesList;
    putRules(value: RulesetRules[] | cdktf.IResolvable): void;
    resetRules(): void;
    get rulesInput(): cdktf.IResolvable | RulesetRules[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
